@@ -29,6 +29,20 @@ class N8NWorkspaceAgentType(StrEnum):
         else:
             return f"{base_url}/demo/{path(agent_type)}"
 
+    @staticmethod
+    def get_n8n_webhook_url_manual_trigger(agent_type: 'N8NWorkspaceAgentType', environment: Environment) -> str:
+        base_url = "https://n8n.letschatty.com/webhook"
+        def path(agent_type: N8NWorkspaceAgentType) -> str:
+            return {
+                N8NWorkspaceAgentType.CALENDAR_SCHEDULER: "calendar_scheduler/manual_trigger",
+                N8NWorkspaceAgentType.TOKKO_BROKER: "tokko_broker/manual_trigger",
+                N8NWorkspaceAgentType.DEFAULT: "default/manual_trigger",
+            }[agent_type]
+        if environment == Environment.PRODUCTION:
+            return f"{base_url}/{path(agent_type)}"
+        else:
+            return f"{base_url}/demo/{path(agent_type)}"
+
 class N8NWorkspaceAgentTypeParameters(BaseModel):
     """Parameters for the N8N workspace agent type"""
     calendars: Optional[List[str]] = Field(default=None, description="List of emails to be used as calendars")
@@ -68,7 +82,6 @@ class ChattyAIAgent(CompanyAssetModel):
     general_objective: str = Field(..., description="General objective/goal of the agent")
     unbreakable_rules: List[str] = Field(default_factory=list, description="List of unbreakable rules")
     control_triggers: List[str] = Field(default_factory=list, description="Triggers for human handoff")
-    integration_user_id : Optional[StrObjectId] = Field(default=None, description="Integration user id")
     test_source_id: Optional[StrObjectId] = Field(default=None, description="Test source id")
     n8n_workspace_agent_type: N8NWorkspaceAgentType = Field(default=N8NWorkspaceAgentType.DEFAULT, description="The type of agent to redirect the message to")
     n8n_workspace_agent_type_parameteres : N8NWorkspaceAgentTypeParameters = Field(default=N8NWorkspaceAgentTypeParameters(), description="The parameters for the N8N workspace agent type")
@@ -85,7 +98,6 @@ class ChattyAIAgent(CompanyAssetModel):
         "name": "Chatty AI Agent 1",
         "personality": "You are a helpful assistant",
         "mode": "autonomous",
-        "integration_user_id": "507f1f77bcf86cd799439011",
         "unbreakable_rules": ["You cannot break the law"],
         "control_triggers": ["You cannot break the law"],
         "n8n_webhook_url": "https://n8n.com/webhook",
@@ -113,13 +125,6 @@ class ChattyAIAgent(CompanyAssetModel):
             raise ValueError("General objective cannot be empty")
         return v.strip()
 
-    @property
-    def integrated_user_id(self) -> StrObjectId:
-        """Get the integrated user id"""
-        if self.integration_user_id is None:
-            raise ValueError(f"Chatty AI Agent {self.id} has no integration user id")
-        return self.integration_user_id
-
     @property
     def test_trigger(self) -> str:
         """Get the test trigger"""
