@@ -18,7 +18,7 @@ class Sale(CompanyAssetModel):
 class SaleRequest(BaseModel):
     product_id: StrObjectId
     quantity: int
-    agent_email: str
+    creator_id: StrObjectId
     total_amount: float
     currency: str
     paid_amount: float
@@ -26,3 +26,14 @@ class SaleRequest(BaseModel):
     details: dict
     crm_id: Optional[str] = Field(default=None)
 
+    def example_payload(self):
+        return {
+            "product_id": "6756ef4959e496069bee54d8",
+            "quantity": 1,
+            "creator_id": "6756ef4959e496069bee54d8",
+            "total_amount": 100,
+            "currency": "USD",
+            "paid_amount": 100,
+            "installments": 1,
+            "details": {}
+        }
\ No newline at end of file
